<div id="header"><a href="/doc">Documentation</a> / Installation and updates</div>

# Installing

NETCO NMS installation packages are distributed in .zip file format.

Copy the package to the target machine.

Ensure the target machine adheres to the [system requirements](index.md#system_requirements)

## Installation instructions for Linux

**1. Extract archive and open terminal in created folder**

Open the target folder with NETCO NMS package in the file manager: ![File manager icon](img/installation_file_manager_icon.png)

Right click on the zip file and select ***Extract here***.

![Extracting zip file](img/installation_extract.png)


**IMPORTANT!**
If you are installing NETCO NMS into a Linux host, it is very important to extract (unzip) the zip-package inside that Linux host, because otherwise file permission bits are not set correctly and this will cause installation to fail partially or completely.


Next, right click on the created folder and select ***Open in Terminal***.

![Open in terminal](img/installation_open_terminal.png)


**2. Launch installer in the terminal**

Issue the following commands:

> chmod +x ./environments/compose-for-single-node-linux.sh

> sudo ./environments/compose-for-single-node-linux.sh

> sudo ./LocalUp.ps1


## Installation instructions for Windows

**1. Extract archive**

Right click on the zip file and select ***Extract All***

Choose the folder where you'd like to extract the NETCO NMS package.

**2. Download and install Docker Desktop for Windows**

Visit [the NETCO NMS Release Notes page](https://online.satel.com/updates/get.aspx?p=satel_netco_nms_ce&f=release_notes) to find information about the recommended version of Docker Desktop. Please note that the latest version of Docker Desktop might not be tested and thus not recommended by Satel. Follow the installation instructions provided at  [https://docs.docker.com/desktop/install/windows-install/](https://docs.docker.com/desktop/install/windows-install/) and select the WSL2 backend option.

If it is requested, please create docker.com user account.

**3. Start Docker Desktop**

Type "Docker" in Windows search box, and select Docker Desktop in the search results.

Set "Start Docker Desktop when you log in" to ON state in the General Settings page.

<img src="img/docker_settings_start.png" style="width: 800px; object-fit: contain;" alt="Docker settings"/>

**4. Enable Unrestricted Execution Policy**

To enable running Powershell scripts, start Powershell with "Run as Administrator" and run the following:

> Set-Executionpolicy Unrestricted

This will prompt:

> Execution Policy Change
> The execution policy helps protect you from scripts that you do not
> trust. Changing the execution policy might expose you to the security
> risks described in the about_Execution_Policies help topic at
> https:/go.microsoft.com/fwlink/?LinkID=135170.
> Do you want to change the execution policy?
> [Y] Yes  [A] Yes to All  [N] No  [L] No to All  [S] Suspend
> [?] Help (default is "N"):

Type **a** and press Enter.

**5. Start the NETCO NMS stack**

Start Powershell with "Run as Administrator", go to the directory where you extracted the zip with ***cd*** command, and run this:

> .\LocalUp.ps1

(!) If you are asked to trust .ps1 scripts in this
  directory during the following steps, please choose
  option R = Run once. You may have to do this 2-3 times
  during installation.

You will be presented a menu where you can change configuration. See more information about the menu in next chapter.

The installation takes some minutes and after that you are presented with an url to direct your browser to and admin username and password. Please save the password for later logins as it is the only way to login as admin.

## Initial configuration

At first LocalUp.ps1 will allow making changes to the initial configuration. The available options are:

**Option** |**OS**| **Description**
|:-- | :- |:------
|1. Allow access to local serial device: none |Linux| For installations where a local serial port on the NETCO NMS machine is used to access the radio network's root node. Common examples may be ***/dev/ttyS0*** or ***/dev/ttyUSB0***. The ttyS* devices are typically hardware serial ports directly on the computer's motherboard. For USB serial adapters the device name can be obtained by looking at `dmesg |tail` output immediately after the adapter has been connected.
|2. Listen address for NETCO NMS user interface: 0.0.0.0 | Win Linux|The default listens to all network interfaces. If NETCO NMS should be restricted to a specific network interface, provide its IP address here.
|3. Listen port for NETCO NMS user interface: 2080 | Win Linux | Listen Port: By default, the application uses port 2080 in Windows and port 80 in Linux.
|4. Retention policy for monitoring data: INF |Win Linux| The time to store monitoring data in the database. The value must be either a number and unit [e.g. '105d'] or 'INF', which will never delete monitoring data. **Note: This can not be changed later.**
|5. Internal Docker address space: 10.99.99.0/24 |Win Linux| NETCO NMS creates a subnet to communicate across its components locally. This address space is not otherwise visible to NETCO NMS users, however it should not collide with networks within the Intranet.
|6. User profile path | Win | NETCO NMS istaller will configure WSL2 to limit memory usage with 4Gb. A file ".wslconfig" will be saved to the user profile folder.

Note: If you are installing NETCO NMS on a Windows machine and wish to establish a serial connection to your devices, it is recommended to utilize port mapping scripts, which can be found in ./win_ports folder. These scripts assist in mapping TCP ports within the Docker container to the serial port on your Windows host machine. More information is in a chapter [Serial ports setup in Windows](win_port.md)


When ***Configure option:*** is prompted, most users can simply press Enter to continue with default settings.

![NETCO NMS LocalUp.ps1 start example](img/installation_localup_example1.png)

<a name="installation_complete" class="anchor"></a>
## Installation complete

Once installation is completed, the terminal will return to a command prompt. NETCO NMS is now installed and running. It will also be started automatically on reboot.

![NETCO NMS LocalUp.ps1 completed example](img/installation_localup_example2.png)

Follow the instructions in green to log in to NETCO NMS. The displayed password is randomly generated and is unique to each system. **Make sure to store or [change the password](user_management.md) for later use.**

# Updating

Simply extract a newer NETCO NMS package to some folder and run ./LocalUp.ps1.

**Note**: A new initial admin password will be generated. If you wish to use your previous admin password, please ensure to copy the .env.secret file from the directory where your previous version of NETCO NMS was extracted before running LocalUp.ps1.


# Uninstalling

Uninstallation involves the following three step process:

* Shut down the NETCO NMS stack:
 * on Ubuntu: open a terminal, enter the extracted NETCO NMS folder and run `sudo ./LocalDown.ps1`
 * on Windows: open PowerShell as Administrator. Enter the extracted NETCO NMS folder and run `.\LocalDown.ps1`
* Remove unused docker images: `docker image prune -a`
* Remove unused docker volumes: `docker volume prune` -- this deletes NETCO NMS data including imported networks and monitoring data

These instructions assume docker was set up specifically for NETCO NMS. If other docker containers are used, make sure to prune NETCO NMS specific containers and volumes only.

