<div id="header"><a href="/doc">Documentation</a> / Monitoring</div>

The **Monitoring** section is built on the open source monitoring framework [Grafana](https://grafana.com/), which is structured around **dashboards** and **panels**. Panels display individual metrics (such as a voltage graph) and the dashboard is a collection of panels arranged in a grid.

A list of existing dashboards is available in the top left corner of the page, next to the main menu.

Dashboards included with NETCO NMS are:

* [Home dashboard](monitoring.md#home_dashboard)
* [Network monitoring dashboard](monitoring.md#network_monitoring_dashboard)
* [Data export dashboard](monitoring.md#data_export_dashboard)
* [System dashboard](monitoring.md#system_monitoring_dashboard)

The option to create [custom dashboards](monitoring.md#custom_dashboards) is also available.

<a name="home_dashboard" class="anchor"></a>
# Home dashboard

Selecting **Monitoring** from the main menu brings the user to the Home dashboard, which is also the default page loaded after logging in.

<img src="img/usage_monitoring_home_dashboard.png" style="width: 1000px; object-fit: contain;" alt="Home dashboard"/>

## Networks list

The Home dashboard lists all networks that have **"Monitoring state"** set to either **"on"** or **"paused"**. To remove a network from this list, change the network's **Monitoring / State** to **"off"** under [Network settings in NETCO Design](design.md#network_monitoring_settings).

The network listing also features quick navigation:

* Network name links the [network monitoring dashboard](monitoring.md#network_monitoring_dashboard)
* The node count opens the network in NETCO Design
* Critical alert count links to alerts view
* Monitoring state also opens the network in NETCO Design

Red highlighting indicates that the network currently has open alerts. On the other hand, green highlighting signals that the network either has no alerts or that all alerts have been acknowledged or closed.

## Node locations map view

The Node Locations view provides quick insights into the status and health of individual devices. Each device is represented as a colored circle, showing its monitoring status. Green means "no alarms," yellow signals a "warning," and red indicates a "critical error." Hover over a circle with your mouse to view detailed information about the node, including its last monitored values.

Geolocation coordinates should be specified in NETCO DESIGN. Select a node, then find the Geolocation setting in the nodes' properties tree view, in the Metainfo section. Enter the node location in the format “Latitude Longitude” (example: 60.402785 23.073595). Remember that Northern latitudes are positive (0..+90 degrees), and Southern latitudes are negative (0….-90 degrees). Similarly, Western (clockwise) longitudes are negative, and Eastern (counter-clockwise) longitudes are positive.

Nodes are shown on the map exclusively for networks under monitoring, where the Monitoring state is 'on'.

You can zoom the map in and out and view node details by hovering the mouse over a node. While browsing the map, it's recommended to set the Grafana dashboard update interval to 'Off.' Remember to set it back to '5s' afterward; otherwise, the view won't be automatically updated.

For demonstration purposes, NETCO automatically sets default coordinates for your network if it's the only network in the system and if no geolocation is assigned to its nodes. If you set coordinates for one node in your network, NETCO will automatically create random coordinates for other nodes around the specified location. Note that this feature works when there is only one network in the system.


<a name="network_monitoring_dashboard" class="anchor"></a>
# Network monitoring dashboard

The Network monitoring dashboard is the default view for monitoring network performance. This dashboard is automatically generated and subject to change with NETCO NMS updates, therefore it can not be modified. A customizable copy of the original can be made, more on that in the [Custom dashboards paragraph](monitoring.md#custom_dashboards).

<img src="img/usage_monitoring_network_dashboard_top.png" style="width: 1000px; object-fit: contain;" alt="Network monitoring dashboard"/>

The main navigation aides in the dashboard are:

* Network and Node selection in top left corner
* Time range selection in top right toolbar
* Update interval selection in top right toolbar


## Live Monitoring Map View

The Live Monitoring Map View panel presents the network topology. Monitoring values are displayed alongside the respective nodes, and for links, Link RSSI and Link SNR (if available) are shown at the top of the link. User can select what values are shown by using dedicated checkboxes.
### Value colors meaning:
- Green: A valid value within the threshold range
- Orange: A value outside the warning threshold range
- Red: A value outside out of the error threshold range
- Gray: An old value, received earlier the Deadband timeout

## Events log

Check the Events Log panel for the newest network logs. It helps spot issues and makes fixing problems easier. The log panel shows up to 500 lines. To get logs from the last ten days, use the script LocalGetEventsLog.ps1.
LocalGetEventsLog.ps1 generates a zip-file containing logs for each monitored network in the system in .csv format.

In the logs, you can find the node name, monitoring method (UNICAST or ANYCAST), setting name and its value.
For efficiency, NETCO utilizes a single request called 'Combined Diagnostic Values' (CDV), which includes Last RSSI, Noise Level, Voltage, and Temperature measurements. Similarly, the 'Link Data' request retrieves values for Link RSSI and Link SNR (if supported by the device).


<a name="data_export_dashboard" class="anchor"></a>
# Data export dashboard

The Data export dashboard allows pulling raw monitoring data in CSV format. To create the CSV file, click the panel name and select "Inspect" -> "Data" -> "Download CSV".

<img src="img/usage_monitoring_data_export_dashboard.png" style="width: 1000px; object-fit: contain;" alt="Data export dashboard"/>


<a name="system_monitoring_dashboard" class="anchor"></a>
# System monitoring dashboard

The NETCO NMS server's system performance can be viewed from the System monitoring dashboard.

<img src="img/usage_monitoring_system_dashboard.png" style="width: 1000px; object-fit: contain;" alt="System monitoring dashboard"/>

<a name="custom_dashboards" class="anchor"></a>
# Custom dashboards

All of the builtin dashboards mentioned above are automatically generated and are not editable.

To make a editable copy of an existing dashboard, open the dashboard to copy, enter dashboard settings in the top right toolbar and select "Save As...".

<img src="img/usage_monitoring_dashboard_settings.png" alt="Dashboard settings in toolbar"/>
<img src="img/usage_monitoring_dashboard_save_as.png" alt="Dashboard settings / Save As..."/>

Within editable dashboards the bottom right corner of each panel has a grab handle that allows resizing. Panels may also be deleted and rearranged. The panel's top bar has a drop down menu that allows editing layout settings and the data queries to visualize.

<img src="img/usage_monitoring_dashboard_panel_dropdown.png" style="object-fit: contain;" alt="Panel dropdown menu"/>

Full documentation on dashboard customization is available at the [Grafana documentation page](https://grafana.com/docs/grafana/).
