#!/bin/bash

echo "$(date '+%Y-%m-%d %H:%M:%S') Start mediator watchdog"
# Variables
MAX_AGE=20
MEDIATOR_CONTAINER="netco_nms-monitoring-mediator-1"
SS_CONTAINER="netco_nms-ss-1"
CS_CONTAINER="netco_nms-cs-1"
API_CONTAINER="netco_nms-api-1"
MONITORED_FILE="/usr/share/Satel/NETCO/mediator0/restart.me"
LOG_CLEANUP_INTERVAL=7200  # 2 hours

# Function to compress and clean logs
compress_and_clean(){
    local service_name="$1"
    local directory="/usr/share/Satel/NETCO/$service_name/logs"
    echo "Cleaning logs for service $service_name"
    cd "$directory" || exit
    find . -type f -mtime +$MAX_AGE -exec rm -v {} \;

    # Find .log files older than 1 day and zip them individually if they are larger than 10MB, then remove the .log file
    find . -type f -name "*.log" -size +20000 -mtime +0 -exec sh -c 'zip -j "$(basename "{}" .zip).zip" "{}" && rm "{}"' \;
}

SERVICES=("cs0" "ss0" "ds0" "controller0" "nml0" "webui0" "ich0" "ichca0" "liveview0" "mediator0" "trace0")

# Function to compress and clean logs for all services
clean_all_logs() {
    for service in "${SERVICES[@]}"; do
        compress_and_clean "$service"
    done
}


# Function to restart containers
restart_containers() {
    echo "Restarting containers..."
    docker restart $MEDIATOR_CONTAINER
    docker restart $SS_CONTAINER
    docker restart $CS_CONTAINER
    docker restart $API_CONTAINER
    echo "Containers have been restarted."
}


# ---------------- MAIN CODE ------------------------------------

# Perform initial log cleanup
echo "Performing initial log cleanup..."
clean_all_logs

# Initialize log cleanup timer
last_cleanup_time=$(date +%s)

# Main loop
while true; do
    
    # Calculate time since last log cleanup
    current_time=$(date +%s)
    time_since_last_cleanup=$((current_time - last_cleanup_time))

    # Perform log cleanup every LOG_CLEANUP_INTERVAL seconds
    if [ $time_since_last_cleanup -ge $LOG_CLEANUP_INTERVAL ]; then
        clean_all_logs        
        last_cleanup_time=$current_time
    fi

    # Check for the monitored file to restart containers
    if [ -f "$MONITORED_FILE" ]; then
        echo "File found! Restarting containers in 5 seconds..."
        sleep 5
        rm "$MONITORED_FILE"
        restart_containers
    fi

    # Sleep for 10 seconds before next check
    sleep 10
done
